@@ -23,7 +23,7 @@ g.shell.GGIR = function(mode=c(1,2),datadir=c(),outputdir=c(),studyname=c(),f0=1
   if (derivef0f1 == TRUE) { # What file to start with?
     f0 = 1
     if (filelist == FALSE) {  # What file to end with?
-      f1 <- length(dir(datadir, recursive = TRUE, pattern = "[.](csv|bin|Rda|wa)")) # modified by JH
+      f1 <- length(dir(datadir, recursive = TRUE, pattern = "[.](csv|bin|Rda|wa|cw)")) # modified by JH
     } else {
       f1 = length(datadir) #modified
     }
@@ -81,7 +81,6 @@ g.shell.GGIR = function(mode=c(1,2),datadir=c(),outputdir=c(),studyname=c(),f0=1
   if (length(which(ls() == "do.bfen")) == 0)  do.bfen = FALSE
   if (length(which(ls() == "do.hfen")) == 0)  do.hfen = FALSE
   if (length(which(ls() == "do.hfenplus")) == 0)  do.hfenplus = FALSE
-  if (length(which(ls() == "do.teLindert2013")) == 0)  do.teLindert2013 = FALSE
   if (length(which(ls() == "do.anglex")) == 0)  do.anglex = FALSE
   if (length(which(ls() == "do.angley")) == 0)  do.angley = FALSE
   if (length(which(ls() == "do.anglez")) == 0)  do.anglez = FALSE
@@ -128,6 +127,9 @@ g.shell.GGIR = function(mode=c(1,2),datadir=c(),outputdir=c(),studyname=c(),f0=1
   if (length(which(ls() == "backup.cal.coef")) == 0)  backup.cal.coef = c()
   if (length(which(ls() == "bout.metric")) == 0)  bout.metric = 1
   if (length(which(ls() == "closedbout")) == 0)  closedbout = FALSE
+  if (length(which(ls() == "IVIS_windowsize_minutes")) == 0)  IVIS_windowsize_minutes=60
+  if (length(which(ls() == "IVIS_epochsize_seconds")) == 0)  IVIS_epochsize_seconds=30
+  
   
   # # specific for part 5
   if (length(which(ls() == "boutcriter.in")) == 0)  boutcriter.in = 0.9
@@ -148,6 +150,8 @@ g.shell.GGIR = function(mode=c(1,2),datadir=c(),outputdir=c(),studyname=c(),f0=1
   if (length(which(ls() == "window.summary.size")) == 0) window.summary.size = 10
   if (length(which(ls() == "dayborder")) == 0)  dayborder = 0
   
+
+  
   cat("\n   g.shell.GGIR {GGIR} by Vincent van Hees\n")
   if (dopart1 == TRUE) {
     cat('\n')
@@ -159,7 +163,6 @@ g.shell.GGIR = function(mode=c(1,2),datadir=c(),outputdir=c(),studyname=c(),f0=1
             do.lfenmo = do.lfenmo,do.en = do.en,
             do.bfen = do.bfen,do.hfen=do.hfen,
             do.hfenplus = do.hfenplus,
-            do.teLindert2013=do.teLindert2013,
             do.anglex=do.anglex,do.angley=do.angley,do.anglez=do.anglez,
             do.roll_med_acc_x=do.roll_med_acc_x,do.roll_med_acc_y=do.roll_med_acc_y,do.roll_med_acc_z=do.roll_med_acc_z,
             do.dev_roll_med_acc_x=do.dev_roll_med_acc_x,do.dev_roll_med_acc_y=do.dev_roll_med_acc_y,do.dev_roll_med_acc_z=do.dev_roll_med_acc_z,
@@ -181,7 +184,9 @@ g.shell.GGIR = function(mode=c(1,2),datadir=c(),outputdir=c(),studyname=c(),f0=1
             boutcriter = boutcriter,ndayswindow=ndayswindow,idloc=idloc,do.imp=do.imp,
             storefolderstructure=storefolderstructure,overwrite=overwrite,epochvalues2csv=epochvalues2csv,
             mvpadur=mvpadur,selectdaysfile=selectdaysfile,bout.metric=bout.metric,window.summary.size=window.summary.size,
-            dayborder=dayborder,closedbout=closedbout,desiredtz=desiredtz)
+            dayborder=dayborder,closedbout=closedbout,desiredtz=desiredtz,
+            IVIS_windowsize_minutes = IVIS_windowsize_minutes,
+            IVIS_epochsize_seconds = IVIS_epochsize_seconds)
   }
   if (dopart3 == TRUE) {
     cat('\n')
